@@ -1,16 +1,12 @@
 package Bencher::Scenario::PerinciSubValidateArgs::Overhead;
 
 our $DATE = '2016-05-24'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-# initialize the validators
-use Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingPSV;
-Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingPSV::foo(a1=>1, a2=>1);
-
 our $scenario = {
     summary => 'Measure validation overhead',
     participants => [
@@ -27,10 +23,19 @@ our $scenario = {
             fcall_template => 'Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateManualDataSah::foo(a1=><a1>, a2=><a2>)',
         },
         {
-            name => 'Rinci::Validate',
-            fcall_template => 'Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingRinciValidate::foo(a1=><a1>, a2=><a2>)',
+            name => 'DZPRV',
+            fcall_template => 'Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingDZPRV::foo(a1=><a1>, a2=><a2>)',
             include_by_default => 0,
         },
+        {
+            name => 'DZPRW',
+            fcall_template => 'Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingDZPRW::foo_dzprw(a1=><a1>, a2=><a2>)',
+            include_by_default => 0,
+        },
+        {
+            name => 'PSW',
+            fcall_template => 'Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingPSW::foo(a1=><a1>, a2=><a2>)',
+        },
         {
             name => 'PSV',
             fcall_template => 'Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingPSV::foo(a1=><a1>, a2=><a2>)',
@@ -60,7 +65,7 @@ Bencher::Scenario::PerinciSubValidateArgs::Overhead - Measure validation overhea
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::PerinciSubValidateArgs::Overhead (from Perl distribution Bencher-Scenarios-PerinciSubValidateArgs), released on 2016-05-24.
+This document describes version 0.003 of Bencher::Scenario::PerinciSubValidateArgs::Overhead (from Perl distribution Bencher-Scenarios-PerinciSubValidateArgs), released on 2016-05-24.
 
 =head1 SYNOPSIS
 
@@ -84,6 +89,8 @@ L<Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateManually>
 
 L<Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateManualDataSah>
 
+L<Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingPSW>
+
 L<Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingPSV>
 
 L<Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingTypeTiny>
@@ -116,7 +123,15 @@ Function call template:
 
 
 
-=item * Rinci::Validate (perl_code) (not included by default)
+=item * DZPRV (perl_code) (not included by default)
+
+Function call template:
+
+ Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingPSW::foo(a1=><a1>, a2=><a2>)
+
+
+
+=item * DZPRW (perl_code) (not included by default)
 
 Function call template:
 
@@ -124,7 +139,7 @@ Function call template:
 
 
 
-=item * PSV (perl_code)
+=item * PSW (perl_code)
 
 Function call template:
 
@@ -132,6 +147,12 @@ Function call template:
 
 
 
+=item * PSV (perl_code)
+
+L<Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingPSV>::foo
+
+
+
 =item * Type::Tiny (perl_code)
 
 L<Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingTypeTiny>::foo
@@ -150,18 +171,19 @@ L<Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingTypeTiny>::foo
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
+Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m PerinciSubValidateArgs::Overhead >>):
 
  +-------------+-----------+-----------+------------+---------+---------+
  | participant | rate (/s) | time (μs) | vs_slowest | errors  | samples |
  +-------------+-----------+-----------+------------+---------+---------+
- | PSV         | 8.4e+04   | 12        | 1          | 1.3e-08 | 20      |
- | manual+dsah | 1.9e+05   | 5.2       | 2.3        | 6.7e-09 | 20      |
- | Type::Tiny  | 2.2e+05   | 4.6       | 2.6        | 5e-09   | 20      |
- | manual      | 4e+05     | 2.5       | 4.8        | 3.3e-09 | 20      |
- | none        | 1.47e+06  | 0.681     | 17.5       | 1.9e-10 | 24      |
+ | PSV         | 5.5e+04   | 18        | 1          | 2.7e-08 | 20      |
+ | PSW         | 7.59e+04  | 13.2      | 1.37       | 6.5e-09 | 21      |
+ | manual+dsah | 1.17e+05  | 8.57      | 2.1        | 3.3e-09 | 20      |
+ | Type::Tiny  | 1.3e+05   | 7.7       | 2.3        | 1.3e-08 | 21      |
+ | manual      | 2.5e+05   | 4         | 4.5        | 5e-09   | 20      |
+ | none        | 2.02e+06  | 0.496     | 36.4       | 1.7e-10 | 29      |
  +-------------+-----------+-----------+------------+---------+---------+
 
 
@@ -170,12 +192,13 @@ Benchmark module startup overhead (C<< bencher -m PerinciSubValidateArgs::Overhe
  +----------------------------------------------------------------------+-----------+------------------------+------------+---------+---------+
  | participant                                                          | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +----------------------------------------------------------------------+-----------+------------------------+------------+---------+---------+
- | Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateManualDataSah | 62        | 57                     | 1          | 0.00017 | 21      |
- | Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingTypeTiny | 41        | 36                     | 1.5        | 4.5e-05 | 20      |
- | Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingPSV      | 13        | 8                      | 4.9        | 3.6e-05 | 20      |
- | Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateManually      | 8.3       | 3.3                    | 7.5        | 3.9e-05 | 20      |
- | Bencher::ScenarioUtil::PerinciSubValidateArgs::NoValidate            | 8.2       | 3.2                    | 7.6        | 3.6e-05 | 20      |
- | perl -e1 (baseline)                                                  | 5         | 0                      | 12         | 2.7e-05 | 24      |
+ | Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingPSW      | 78        | 73.6                   | 1          | 0.00038 | 20      |
+ | Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateManualDataSah | 69        | 64.6                   | 1.1        | 0.0003  | 21      |
+ | Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingTypeTiny | 47        | 42.6                   | 1.7        | 0.00011 | 22      |
+ | Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateUsingPSV      | 13        | 8.6                    | 6          | 8.6e-05 | 20      |
+ | Bencher::ScenarioUtil::PerinciSubValidateArgs::ValidateManually      | 8.2       | 3.8                    | 9.6        | 5.6e-05 | 21      |
+ | Bencher::ScenarioUtil::PerinciSubValidateArgs::NoValidate            | 7.8       | 3.4                    | 10         | 2.4e-05 | 20      |
+ | perl -e1 (baseline)                                                  | 4.4       | 0                      | 18         | 3.1e-05 | 21      |
  +----------------------------------------------------------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
@@ -184,8 +207,17 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 =head1 BENCHMARK NOTES
 
-C<manual> is faster than C<Rinci::Validate>, which is slightly faster than
-C<Type::Tiny>, which is faster than C<PSV> and C<manual+dsah>.
+The Type::Tiny, Data::Sah, Perinci::Sub::ValidateArgs participants (except
+C<none>, obviously) all should be in the same order of magnitude because both
+L<Data::Sah> and L<Type::Tiny> work by generating Perl code validator and then
+compiling (C<eval()>) them then execute the compiled result. The differences are
+in the details: how the generated Perl code is structured, what the code for the
+type checks are (e.g. checking for number can be done with a regex or
+L<Scalar::Util>'s C<looks_like_number()> or L<Scalar::Util::Numeric>, and so
+on).
+
+Perinci::Sub::Wrapper (PSW) and Dist::Zilla::Plugin::Rinci::Wrap is slower
+because it does more.
 
 =head1 HOMEPAGE
 
