@@ -1,7 +1,7 @@
 package Bencher::Scenario::PerinciSubValidateArgs::Startup;
 
 our $DATE = '2016-05-24'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -43,7 +43,7 @@ Bencher::Scenario::PerinciSubValidateArgs::Startup - Benchmark startup of Perinc
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::PerinciSubValidateArgs::Startup (from Perl distribution Bencher-Scenarios-PerinciSubValidateArgs), released on 2016-05-24.
+This document describes version 0.003 of Bencher::Scenario::PerinciSubValidateArgs::Startup (from Perl distribution Bencher-Scenarios-PerinciSubValidateArgs), released on 2016-05-24.
 
 =head1 SYNOPSIS
 
@@ -79,16 +79,16 @@ Load Perinci::Sub::ValidateArgs (PSV) and run a function that uses PSV for the f
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
+Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m PerinciSubValidateArgs::Startup >>):
 
  +--------------------+-----------+-----------+------------+---------+---------+
  | participant        | rate (/s) | time (ms) | vs_slowest | errors  | samples |
  +--------------------+-----------+-----------+------------+---------+---------+
- | load_psv+first_run | 16        | 62        | 1          | 0.0002  | 20      |
- | load_psv           | 75        | 13        | 4.6        | 7.7e-05 | 20      |
- | perl               | 1.9e+02   | 5.1       | 12         | 3.7e-05 | 22      |
+ | load_psv+first_run | 15        | 67        | 1          | 0.0002  | 20      |
+ | load_psv           | 81        | 12        | 5.4        | 4.2e-05 | 20      |
+ | perl               | 2e+02     | 5         | 1e+01      | 7.5e-05 | 20      |
  +--------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
